@@ -269,6 +269,11 @@ class Atoms(object):
         """Get number of atoms."""
         return len(self.coords)
 
+    @property
+    def uniq_species(self):
+        """Get unique elements."""
+        return list(set(self.elements))
+
     def get_center_of_mass(self):
         """Get center of mass of the atoms object."""
         # atomic_mass
@@ -781,10 +786,10 @@ def add_atoms(top, bottom, distance=[0, 0, 5]):
     elements = []
     coords = []
     lattice_mat = bottom.lattice_mat
-    for i, j in zip(bottom.elements, bottom.cart_coords):
+    for i, j in zip(bottom.elements, bottom.frac_coords):
         elements.append(i)
         coords.append(j)
-    for i, j in zip(top.elements, top.cart_coords):
+    for i, j in zip(top.elements, top.frac_coords):
         elements.append(i)
         coords.append(j)
 
@@ -795,7 +800,7 @@ def add_atoms(top, bottom, distance=[0, 0, 5]):
         lattice_mat=lattice_mat,
         coords=coords,
         elements=elements,
-        cartesian=True,
+        cartesian=False,
     ).center_around_origin()
     return combined
 
@@ -817,6 +822,17 @@ def fix_pbc(atoms):
     )
 
 
+def get_supercell_dims(atoms, enforce_c_size=10, extend=1):
+    """Get supercell dimensions."""
+    a = atoms.lattice.lat_lengths()[0]
+    b = atoms.lattice.lat_lengths()[1]
+    c = atoms.lattice.lat_lengths()[2]
+    dim1 = int(float(enforce_c_size) / float(a)) + extend
+    dim2 = int(float(enforce_c_size) / float(b)) + extend
+    dim3 = int(float(enforce_c_size) / float(c)) + extend
+    return [dim1, dim2, dim3]
+
+
 """
 if __name__ == "__main__":
     box = [[2.715, 2.715, 0], [0, 2.715, 2.715], [2.715, 0, 2.715]]
